@@ -4,7 +4,7 @@ use swc_atoms::js_word;
 use swc_common::{
     pass::{CompilerPass, Repeated},
     util::{move_map::MoveMap, take::Take},
-    Spanned, DUMMY_SP,
+    Mark, Spanned, DUMMY_SP,
 };
 use swc_ecma_ast::*;
 use swc_ecma_transforms_base::pass::RepeatedJsPass;
@@ -23,7 +23,7 @@ mod tests;
 /// Not intended for general use. Use [simplifier] instead.
 ///
 /// Ported from `PeepholeRemoveDeadCode` of google closure compiler.
-pub fn dead_branch_remover() -> impl RepeatedJsPass + VisitMut + 'static {
+pub fn dead_branch_remover(_top_level_mark: Mark) -> impl RepeatedJsPass + VisitMut + 'static {
     as_folder(Remover::default())
 }
 
@@ -468,10 +468,10 @@ impl VisitMut for Remover {
                     Stmt::Empty(EmptyStmt { span: v.span })
                 }
 
-                Stmt::Labeled(LabeledStmt { span, body, .. }) if body.is_empty() => {
-                    if cfg!(feature = "debug") {
-                        debug!("Dropping an empty label statement");
-                    }
+                Stmt::Labeled(LabeledStmt {
+                    label, span, body, ..
+                }) if body.is_empty() => {
+                    debug!("Dropping an empty label statement: `{}`", label);
                     Stmt::Empty(EmptyStmt { span })
                 }
 
@@ -485,9 +485,7 @@ impl VisitMut for Remover {
                     _ => false,
                 } =>
                 {
-                    if cfg!(feature = "debug") {
-                        debug!("Dropping a label statement with instant break");
-                    }
+                    debug!("Dropping a label statement with instant break: `{}`", label);
                     Stmt::Empty(EmptyStmt { span })
                 }
 
